@@ -4,6 +4,3 @@ import social_core
 print("import: 'social_core.backends'")
 import social_core.backends
 
-print("import: 'social_core.pipeline'")
-import social_core.pipeline
-
